***********************
Wait Wait Stats Library
***********************

The Wait Wait Stats Library, ``wwdtm`` is a Python library that is used to
query data regarding guests, hosts, locations, panelists, scorekeepers and
shows from a copy of the Wait Wait Stats database.

wwdtm Library
=============

The Wait Wait Stats Library includes a set of modules and a corresponding set
of ``pytest`` testing modules. The documentation for each module is available
via the links below.

Packaged versions of the ``wwdtm`` library are available at `PyPI`_.

Migrating to v2
===============

With the new major version bump for the ``wwdtm`` library, there have been a
large number of API changes from ``wwdtm`` version 1.x to the current version.
This section of the documentation will provide a summary of changes and
changes to function/method locations.

Known Issues
============

A list of known issues is documented in the ":doc:`/known_issues`" page.

Table of Contents
=================

.. toctree::
    :maxdepth: 1

    known_issues
    wwdtm/index
    tests/index
    migrating/index
    changes/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _PyPI: https://pypi.org/project/wwdtm/
